from datetime import datetime

import pymysql


class MySQLClient:
    def __init__(self, host, user, password, db, port=3306):
        self.conn = pymysql.connect(
            host=host,
            user=user,
            password=password,
            db=db,
            port=port,
            charset='utf8mb4',
            cursorclass=pymysql.cursors.DictCursor,
            autocommit=True
        )
        self.cursor = self.conn.cursor()

    def execute(self, sql, values=None):
        try:
            self.cursor.execute(sql, values or [])

        except Exception as e:
            print(f"[MySQL] 执行失败: {e}")
            self.conn.rollback()

    def __del__(self):
        try:
            self.cursor.close()
            self.conn.close()
        except Exception:
            pass


class DB:
    _client: MySQLClient = None  # 类属性持有连接

    @classmethod
    def init(cls):
        if cls._client is None:
            cls._client = MySQLClient(
                host='39.101.135.56',
                user='tsreshub_prod',
                password='Tr5h$Prod!92@TsRH',
                db='tsreshub_db',
                port=3306
            )

    @classmethod
    def insert_resume(cls, data: dict):
        cls.init()  # 保证连接已初始化

        safe_data = {k: v for k, v in data.items() if isinstance(v, (str, int, float, type(None), datetime))}

        table = 'resumes_resumebasic'
        keys = ', '.join(safe_data.keys())
        placeholders = ', '.join(['%s'] * len(safe_data))
        update_clause = ', '.join([f"{k} = VALUES({k})" for k in safe_data if k != 'resume_id'])

        sql = f"""
            INSERT INTO {table} ({keys}) VALUES ({placeholders})
            ON DUPLICATE KEY UPDATE {update_clause}
            """

        cls._client.execute(sql, list(safe_data.values()))
